Crate oxapi_impl

Crate oxapi_impl 

Core implementation for the oxapi OpenAPI server stub generator.

Structs

Generator
Main generator that coordinates all the pieces.
GeneratorBuilder
Builder for configuring and creating a Generator.
MethodTransformer
Transforms user-defined trait methods based on OpenAPI operations.
Operation
A parsed OpenAPI operation.
OperationParam
A parsed operation parameter.
ParsedSpec
Parsed OpenAPI specification.
ResponseGenerator
Generator for response enums.
ResponseSuffixes
Configuration for response type suffixes and derives.
RouterGenerator
Generator for axum router code.
TypeGenerator
Type generator that wraps typify’s TypeSpace.
TypeOverrideKey
Key for looking up type overrides.
TypeOverrides
Collection of type overrides for generated types.
TypeSpacePatch
Contains a set of modifications that may be applied to an existing type.
TypeSpaceSettings
Settings that alter type generation.
VariantOverride
Variant override info: name, inner type name, and attributes to pass through.

Enums

Error
GeneratedTypeKind
Kind of generated type for an operation.
HttpMethod
HTTP methods supported by OpenAPI.
ParamLocation
Location of a parameter.
TypeOverride
Override for a generated type - either rename or replace.

Type Aliases

Result