TypeGenerator

Struct TypeGenerator 

pub struct TypeGenerator { /* private fields */ }
Type generator that wraps typify’s TypeSpace.

Implementations

Source

impl TypeGenerator

pub fn new(spec: &ParsedSpec) -> Result<Self>

Create a new type generator from a parsed spec.

pub fn generate_all_types(&self) -> TokenStream

Generate all types as a TokenStream.

pub fn get_type_name(&self, reference: &str) -> Option<String>

Get the type name for a schema reference.

pub fn type_for_schema( &self, schema: &ReferenceOr<Schema>, name_hint: &str, ) -> TokenStream

Generate a type for an inline schema.

pub fn type_for_boxed_schema( &self, schema: &ReferenceOr<Box<Schema>>, name_hint: &str, ) -> TokenStream

Generate a type for a boxed schema reference.

pub fn path_param_type(&self, param: &OperationParam) -> TokenStream

Get the type for a path parameter.

pub fn query_param_type(&self, param: &OperationParam) -> TokenStream

Get the type for a query parameter.

pub fn request_body_type( &self, body: &RequestBody, op_name: &str, ) -> TokenStream

Get the type for a request body.

pub fn response_type( &self, schema: &Option<ReferenceOr<Schema>>, op_name: &str, status: u16, ) -> TokenStream

Get the type for a response body.

pub fn generate_query_struct( &self, op: &Operation, ) -> Option<(Ident, TokenStream)>

Generate a query params struct for an operation.

pub fn generate_path_type(&self, op: &Operation) -> TokenStream

Generate a path params type for an operation (usually a tuple).